data {
    int NSt;
    int K;
    real Sts[NSt];
    int Rs[NSt, K];
}
transformed data {
    vector[NSt+1] a_Psis;
    vector[K-2] a_C;
    
    for (i in 1:(NSt+1)) {
        a_Psis[i] = 1.0;
    }
    for (i in 1:(K-2)) {
        a_C[i] = 1.0;
    }
}
parameters {
    simplex[NSt+1] prePsis;
    simplex[K-2] preC;
    real<lower = 0.0> a;
    real<lower = 0.0> b;
}
transformed parameters {
    real Psis[NSt];
    real sgms[NSt];
    real C[K-1];
    simplex[K] theta[NSt];
    real v;

    v = 0.0;
    for (s in 1:NSt) {
        v = v + prePsis[s];
        Psis[s] = logit(v);
    }
    
    for (s in 1:NSt) {
        sgms[s] = a + b * (Psis[s] - Psis[1]);
    }
    C[1] = 0.0;
    C[K-1] = 1.0;
    v = 0.0;
    for (k in 2:(K-2)) {
        v = v + preC[k-1];
        C[k] = C[1] + v;
    }
    for (s in 1:NSt) {
        theta[s][1] = normal_cdf(C[1], Psis[s], sgms[s]);
        theta[s][K] = 1.0 - normal_cdf(C[K-1], Psis[s], sgms[s]);
        for (k in 2:(K-1)) {
            theta[s][k] = normal_cdf(C[k], Psis[s], sgms[s]) -
                            normal_cdf(C[k-1], Psis[s], sgms[s]);
        }
    }
}
model {
    prePsis ~ dirichlet(a_Psis);
    preC ~ dirichlet(a_C);
    a ~ exponential(0.001);
    b ~ exponential(0.001);
    for (s in 1:NSt) {
        Rs[s] ~ multinomial(theta[s]);
    }
}
